@@ -3,13 +3,12 @@ from refdatatypes.refbase import RefBase
 
 class RefBool(RefBase):
     def __init__(self, value_: bool):
-        super().__init__()
-        self.value = value_
+        super().__init__(value_)
 
     @property
     def value(self) -> bool:
-        return self._value[0]
+        return super().value
 
     @value.setter
     def value(self, value_: bool):
-        self._value[0] = bool(value_)
+        super()._base_value_setter(bool(value_))
